@@ -105,6 +105,7 @@ const ErrorBox = new Lang.Class({
         this._secondaryLabel =
             new Gtk.Label({ label: '',
                             use_markup: true,
+                            wrap: true,
                             halign: Gtk.Align.CENTER,
                             valign: Gtk.Align.CENTER });
         this.widget.add(this._secondaryLabel);
@@ -214,6 +215,10 @@ const Embed = new Lang.Class({
         this.widget = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                     visible: true });
 
+        // create the toolbar for selected items, it's hidden by default
+        this._selectionToolbar = new Selections.SelectionToolbar();
+        this.widget.pack_end(this._selectionToolbar.widget, false, false, 0);
+
         this._stackOverlay = new Gtk.Overlay({ visible: true });
         this.widget.pack_end(this._stackOverlay, true, true, 0);
 
@@ -222,10 +227,6 @@ const Embed = new Lang.Class({
                                       transition_type: Gtk.StackTransitionType.CROSSFADE });
         this._stackOverlay.add(this._stack);
 
-        // create the OSD toolbar for selected items, it's hidden by default
-        this._selectionToolbar = new Selections.SelectionToolbar();
-        this._stackOverlay.add_overlay(this._selectionToolbar.widget);
-
         // pack the OSD notification widget
         this._stackOverlay.add_overlay(Application.notificationManager.widget);
 
@@ -425,12 +426,10 @@ const Embed = new Lang.Class({
         if (this._edit)
             this._edit.setUri(null);
 
-        if (this._toolbar)
-            this._toolbar.widget.destroy();
-
         // pack the toolbar
         this._toolbar = new MainToolbar.OverviewToolbar(this._stackOverlay);
-        this.widget.pack_start(this._toolbar.widget, false, false, 0);
+        let toplevel = Application.application.get_windows()[0];
+        toplevel.set_titlebar(this._toolbar.widget);
 
         this._spinnerBox.stop();
         this._stack.set_visible_child_name('view');
@@ -439,23 +438,21 @@ const Embed = new Lang.Class({
     _prepareForPreview: function() {
         if (this._edit)
             this._edit.setUri(null);
-        if (this._toolbar)
-            this._toolbar.widget.destroy();
 
         // pack the toolbar
         this._toolbar = new Preview.PreviewToolbar(this._preview);
-        this.widget.pack_start(this._toolbar.widget, false, false, 0);
+        let toplevel = Application.application.get_windows()[0];
+        toplevel.set_titlebar(this._toolbar.widget);
     },
 
     _prepareForEdit: function() {
         if (this._preview)
             this._preview.setModel(null);
-        if (this._toolbar)
-            this._toolbar.widget.destroy();
 
         // pack the toolbar
         this._toolbar = new Edit.EditToolbar(this._preview);
-        this.widget.pack_start(this._toolbar.widget, false, false, 0);
+        let toplevel = Application.application.get_windows()[0];
+        toplevel.set_titlebar(this._toolbar.widget);
 
         this._stack.set_visible_child_name('edit');
     },
