@@ -137,7 +137,7 @@ const BaseManager = new Lang.Class({
     },
 
     forEachItem: function(func) {
-        for (idx in this._items)
+        for (let idx in this._items)
             func(this._items[idx]);
     },
 
@@ -154,6 +154,7 @@ const BaseManager = new Lang.Class({
 
     processNewItems: function(newItems) {
         let oldItems = this.getItems();
+        let idx;
 
         for (idx in oldItems) {
             let item = oldItems[idx];
@@ -213,7 +214,7 @@ const BaseModel = new Lang.Class({
         }
 
         let items = this._manager.getItems();
-        for (idx in items) {
+        for (let idx in items) {
             let item = items[idx];
             iter = this.model.append();
             this.model.set(iter,
@@ -230,10 +231,10 @@ const BaseView = new Lang.Class({
         this._model = new BaseModel(manager);
         this._manager = manager;
 
-        this.widget = new Gtk.TreeView({ headers_visible: false,
+        this.widget = new Gtk.TreeView({ activate_on_single_click: true,
+                                         headers_visible: false,
                                          enable_search: false });
         this._treeView = this.widget;
-        GdPrivate.gtk_tree_view_set_activate_on_single_click(this._treeView, true);
         this._treeView.set_model(this._model.model);
 
         let selection = this._treeView.get_selection();
